@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.db import models
 from django.test import TestCase
+from django.utils.safestring import SafeString
 
 from django_bleach.models import BleachField
 from testproject.constants import (
@@ -25,6 +26,7 @@ class BleachContent(models.Model):
     )
     choice = BleachField(choices=CHOICES)
     blank_field = BleachField(blank=True)
+    null_field = BleachField(blank=True, null=True)
 
 
 class TestBleachModelField(TestCase):
@@ -55,6 +57,27 @@ class TestBleachModelField(TestCase):
             obj = BleachContent.objects.create(content=value)
             self.assertEqual(obj.content, expected_values[key])
 
+    def test_retrieved_values_are_template_safe(self):
+        obj = BleachContent.objects.create(content="some content")
+        obj.refresh_from_db()
+        self.assertIsInstance(obj.content, SafeString)
+        obj = BleachContent.objects.create(content="")
+        obj.refresh_from_db()
+        self.assertIsInstance(obj.content, SafeString)
+
+    def test_saved_values_are_template_safe(self):
+        obj = BleachContent(content="some content")
+        obj.save()
+        self.assertIsInstance(obj.content, SafeString)
+        obj = BleachContent(content="")
+        obj.save()
+        self.assertIsInstance(obj.content, SafeString)
+
+    def test_saved_none_values_are_none(self):
+        obj = BleachContent(null_field=None)
+        obj.save()
+        self.assertIsNone(obj.null_field)
+
 
 class BleachNullableContent(models.Model):
     """ Bleach test model"""
